@@ -1,23 +1,25 @@
+import copy
 import curses
 import weakref
 from typing import Callable
 
 import npyscreen
 from npyscreen import BoxTitle, MultiLine, TextCommandBox, Pager
+from npyscreen.wgmultiline import MORE_LABEL
 from prompt_toolkit.completion import WordCompleter
 
 from figcli.commands.config.get import Get
 from figcli.commands.config_context import ConfigContext
 from figcli.commands.types.config import ConfigCommand
 from figcli.io.output import OutUtils
-from figcli.models.run_env import RunEnv
+from figgy.models.run_env import RunEnv
 from figcli.svcs.config import ConfigService, ParameterUndecryptable
 from figcli.svcs.observability.anonymous_usage_tracker import AnonymousUsageTracker
 from figcli.svcs.observability.version_tracker import VersionTracker
 from figcli.utils.utils import *
 from figcli.views.rbac_limited_config import RBACLimitedConfigView
 
-QUIT_CODES = [':q', 'quit', 'exit', ":wq", "q", "/quit"]
+QUIT_CODES = [':q', 'quit', 'exit', ":wq", "q", "/quit", "/q"]
 
 
 class List(ConfigCommand):
@@ -45,6 +47,7 @@ class ActionControllerSearch(npyscreen.ActionControllerSimple):
     """
     Adds filter functionality to the select box at the bottom.
     """
+
     def create(self):
         self.add_action('^/.*', self.set_search, True)
 
@@ -58,6 +61,7 @@ class SelectBox(TextCommandBox):
     """
     Select box at the bottom of the list view.
     """
+
     def __init__(self, screen, *args, **keywords):
         super().__init__(screen, *args, **keywords)
         self.max_width = self.width / 2
@@ -75,13 +79,20 @@ class SelectBox(TextCommandBox):
 
 
 class SelectedValueBox(BoxTitle):
-    """Creates box around Lookup Box"""
+    """Creates box around Value"""
     _contained_widget = MultiLine
 
+
+class LegendBox(BoxTitle):
+    """Creates box around Legend"""
+    _contained_widget = MultiLine
+
+
 class SelectableMultiline(MultiLine):
     """
     Main list-view display box that allows users to select options
     """
+
     def set_select_callback(self, callback: Callable):
         self.select_callback = callback
 
@@ -103,8 +114,8 @@ class SelectableMultiline(MultiLine):
             curses.KEY_DOWN: self.h_cursor_line_down,
             ord('j'): self.h_cursor_line_down,
             curses.KEY_RIGHT: self.h_cursor_line_down,
-            curses.KEY_NPAGE: self.h_cursor_page_down,
-            curses.KEY_PPAGE: self.h_cursor_page_up,
+            'd': self.h_cursor_page_down,
+            'u': self.h_cursor_page_up,
             curses.ascii.TAB: self.h_exit_down,
             curses.ascii.NL: self.h_select_exit,
             curses.KEY_HOME: self.h_cursor_beginning,
@@ -112,7 +123,6 @@ class SelectableMultiline(MultiLine):
             ord('g'): self.h_cursor_beginning,
             ord('G'): self.h_cursor_end,
             ord('x'): self.h_select,
-            # "^L":        self.h_set_filtered_to_selected,
             curses.ascii.SP: self.h_select,
             curses.ascii.ESC: self.h_exit_escape,
             curses.ascii.CR: self.h_select_exit,
@@ -125,7 +135,6 @@ class SelectableMultiline(MultiLine):
                 ord('n'): self.move_next_filtered,
                 ord('N'): self.move_previous_filtered,
                 ord('p'): self.move_previous_filtered,
-                # "^L":        self.h_set_filtered_to_selected,
 
             })
 
@@ -143,20 +152,49 @@ class SelectableMultiline(MultiLine):
             # (self.t_input_isprint, self.h_find_char)
         ]
 
+
 class FiggyListForm(npyscreen.FormMuttActive):
+    BUFFER = 1
+    BUFFER_LEFT = 3
+    LEGEND = [
+        "",
+        "< TAB > - Swap between Select / Filter",
+        "< s, ENTER > - Select + Lookup a fig.",
+        "< ↑, k > - Up",
+        "< ↓, j > - Down",
+        "< u > - Page Up",
+        "< d > - Page Down",
+        "< F > - Find - Select window only",
+        ""
+    ]
+
     """
     Form wrapper for entire list view
     """
+
     ACTION_CONTROLLER = ActionControllerSearch
     COMMAND_WIDGET_CLASS = SelectBox
     MAIN_WIDGET_CLASS = SelectableMultiline
 
     def __init__(self, cfg: ConfigService, *args, **keywords):
         super().__init__(*args, **keywords)
-        relx, rely = int(self.columns / 2) * - 1, int(self.lines) * - 1
-        max_height, max_width = int(self.lines / 2) - 1, int(self.columns / 2) - 1
-        self.value_box = self.add_widget(SelectedValueBox, name="Parameter Value: ", relx=relx, rely=rely,
-                                         max_height=max_height, max_width=max_width, allow_filtering=False, editable=False)
+
+        # Legend Box Relative Location
+        leg_relx, leg_rely = int(self.columns / 2) * -1 + self.BUFFER_LEFT, int(self.lines + self.BUFFER) * -1
+        leg_max_height = len(self.LEGEND) + 2
+        leg_max_width = int(self.columns / 2) - self.BUFFER - self.BUFFER_LEFT
+
+        # Value Box Relative Location
+        val_relx, val_rely = int(self.columns / 2) * - 1 + self.BUFFER_LEFT, int(self.lines / 2 + self.BUFFER) * -1
+        val_max_height, val_max_width = int(self.lines / 2), int(self.columns / 2) - self.BUFFER - self.BUFFER_LEFT
+
+        self.legend_box = self.add_widget(LegendBox, name="Legend", relx=leg_relx, rely=leg_rely,
+                                          max_height=leg_max_height, max_width=leg_max_width,
+                                          allow_filtering=False, editable=False, values=self.LEGEND)
+
+        self.value_box = self.add_widget(SelectedValueBox, name="Parameter Value: ", relx=val_relx, rely=val_rely,
+                                         max_height=val_max_height, max_width=val_max_width, allow_filtering=False,
+                                         editable=False)
 
         self.wMain.set_select_callback(self.update_value_box)
         self._cfg = cfg
@@ -167,16 +205,18 @@ class FiggyListForm(npyscreen.FormMuttActive):
         """
         self.value_box.name = ps_name
         self.value_box.update()
+
         try:
             val, desc, = self._cfg.get_parameter_with_description(ps_name)
         except ParameterUndecryptable:
             val = "Undecryptable"
             desc = "You do not have access to decrypt this parameter."
 
-        desc_lines = OutUtils.to_lines(desc, int(self.columns / 2) - 5)
+        desc = desc if desc else ''
+        desc_lines = OutUtils.to_lines(desc, int(self.columns / 2 - self.BUFFER - self.BUFFER_LEFT))
         self.value_box.values = ["",
                                  "Value: ",
-                                 f"    > {val}",
+                                 f"    > asdf",
                                  "",
                                  "Description: ",
                                  f"---",
@@ -196,7 +236,8 @@ class FiggyListForm(npyscreen.FormMuttActive):
         if self.__class__.MAIN_WIDGET_CLASS:
             self.wMain = self.add(self.__class__.MAIN_WIDGET_CLASS,
                                   rely=self.__class__.MAIN_WIDGET_CLASS_START_LINE,
-                                  relx=0, max_height=-2, max_width=MAXX)
+                                  relx=self.BUFFER_LEFT, max_height=-3, max_width=MAXX, editable=True
+                                  )
 
         self.wStatus2 = self.add(self.__class__.STATUS_WIDGET_CLASS, rely=MAXY - 2 - self.BLANK_LINES_BASE,
                                  relx=self.__class__.STATUS_WIDGET_X_OFFSET,
@@ -208,7 +249,7 @@ class FiggyListForm(npyscreen.FormMuttActive):
         else:
             self.wCommand = self.add(
                 self.__class__.COMMAND_WIDGET_CLASS, name=self.__class__.COMMAND_WIDGET_NAME,
-                rely=MAXY - 1 - self.BLANK_LINES_BASE, relx=0,
+                rely=MAXY - 1 - self.BLANK_LINES_BASE, relx=self.BUFFER_LEFT,
                 begin_entry_at=self.__class__.COMMAND_WIDGET_BEGIN_ENTRY_AT,
                 allow_override_begin_entry_at=self.__class__.COMMAND_ALLOW_OVERRIDE_BEGIN_ENTRY_AT)
 
@@ -226,6 +267,7 @@ class ListApp(npyscreen.NPSApp):
     """
     List application wrapper for List form.
     """
+
     def __init__(self, view: RBACLimitedConfigView, cfg: ConfigService, env: RunEnv):
         self._view = view
         self._env = env
@@ -233,10 +275,8 @@ class ListApp(npyscreen.NPSApp):
 
     def main(self):
         F = FiggyListForm(self._cfg)
-        F.wStatus1.value = f"<TAB> Swaps - <s, enter> Selects - < ↑, ↓, j, k> move - <F> Find"
+        F.wStatus1.value = f"Figs"
         F.wStatus2.value = "Filter: </search-query> <quit>"
         F.value.set_values(self._view.get_config_names())
-        F.wMain.editable = True
         F.wMain.values = F.value.get()
         F.edit()
-
