@@ -7,7 +7,7 @@ from figcli.utils.collection_utils import CollectionUtils
 CLEANUP_REPLICA_ORPHANS = "Some stray replication mappings were discovered for your service. " \
                           "Once they are no longer necessary please clean them up using the `prune` command."
 SHARED_NAME_RESOLUTION_MESSAGE = f"Your application is missing at least one ParameterStore name that it expects to " \
-                                 f"exist as defined in either the {SHARED_KEY} block of your configuration, or as a " \
+                                 f"exist as defined in either the [[{SHARED_KEY}]] block of your configuration, or as a " \
                                  f"dependency of a merge key. To resolve " \
                                  f"this, contact whoever is responsible for sharing these config value(s) with you " \
                                  f"and have them setup up config replication of the values into your apps namespace " \
@@ -18,9 +18,7 @@ COMMAND_PARSER_DESC = "Provides utilities to help manage application configs and
                       f"For more details on commands, run: `{CLI_NAME} [resource] [command] --help`"
 CONFIG_REQ_TEXT = f"--config is a requirement argument."
 CI_CONFIG_HELP_TEXT = f"Path to your project's figgy.json file."
-UNUSED_CONFIG_DETECTED = f"%%red%%The following Names were found in PS but are not referenced in your configurations. \n" \
-                         f"Use the %%rs%%%%blue%%`prune`%%rs%%%%red%% command to clean them up once all " \
-                         f"deployed application versions no longer use these configurations: %%rs%%"
+
 
 # Help Text
 VERSION_HELP_TEXT = f'Prints current version, which is, in this case: {VERSION}'
@@ -39,7 +37,7 @@ INFO_HELP_TEXT = f"Prints out more detailed information about the selected subco
 CONFIGURE_HELP_TEXT = f"(Optional) Setup default configurations to reduce redundant prompts."
 EMPTY_ENV_HELP_TEXT = f"No --env parameter found. Using default: "
 DELETE_HELP_TEXT = f"Manually delete parameters from Parameter Store"
-LIST_HELP_TEXT = f"Lists all matching configuration Names based on a namespace prefix. e.g. /app/demo-time/"
+LIST_HELP_TEXT = f"List, filter, and lookup parameters."
 PUT_HELP_TEXT = f"Store (or update) an arbitrary configuration in ParameterStore."
 SHARE_HELP_TEXT = f"Share a parameter from a source to an arbitrary destination path in Parameter Store via config " \
                   f"replication."
@@ -50,7 +48,7 @@ MIGRATE_HELP_TEXT = f"Walks a user through migrating application configs from Co
 SYNC_HELP_TEXT = "Synchronizes your defined figgy.json configurations with those in Parameter Store. " \
                  "This ensures the proper configurations exist in the provided run environment for your application."
 GET_HELP_TEXT = "Retrieve an arbitrary value from ParameterStore by Name."
-BROWSE_HELP_TEXT = "Browse and look up or delete parameters through a tree structure."
+BROWSE_HELP_TEXT = "Browse, look up, and delete parameters through a tree structure."
 AUDIT_HELP_TEXT = "Audit parameter store changes to parameters."
 DUMP_HELP_TEXT = "Dump a series of PS Values by a queried prefix as JSON, or output to a file."
 PREFIX_HELP_TEXT = "The prefix (e.g. /app/demo-time) to limit results to."
