@@ -1,5 +1,7 @@
 import pexpect
 from figcli.test.cli.config import *
+from figcli.test.cli.dev.delete import DevDelete
+from figcli.test.cli.dev.put import DevPut
 from figcli.test.cli.figgy import FiggyTest
 from figcli.config import *
 from figcli.utils.utils import *
@@ -13,9 +15,17 @@ class DevGet(FiggyTest):
                                        timeout=20, encoding='utf-8'), extra_args=extra_args)
 
     def run(self):
+        self.step(f"Preparing get by adding: {param_1}")
+        put = DevPut(extra_args=self.extra_args)
+        put.add(param_1, param_1_val, param_1_desc, add_more=False)
+
         self.step(f"Testing GET for {param_1}")
         self.get(param_1, param_1_val, get_more=False)
 
+        self.step(f"Cleaning up: {param_1}")
+        delete = DevDelete(extra_args=self.extra_args)
+        delete.delete(param_1, check_delete=True, delete_another=False)
+
     def get(self, key, value, get_more=False, expect_missing=False, no_decrypt=False):
         self.expect('.*PS Name.*')
         self.sendline(key)
@@ -33,4 +43,4 @@ class DevGet(FiggyTest):
             self.sendline('y')
         else:
             print("Not getting another")
-            self.sendline('n')
+            self.sendline('n')
\ No newline at end of file
