@@ -1,13 +1,14 @@
 import sys
 
 import pexpect
+
+from figcli.test.cli.actions.delete import DeleteAction
+from figcli.test.cli.actions.put import PutAction
 from figcli.test.cli.config import *
-from figcli.test.cli.dev.get import DevGet
-from figcli.test.cli.dev.delete import DevDelete
-from figcli.test.cli.dev.put import DevPut
 
 from figcli.test.cli.figgy import FiggyTest
 from figcli.config import *
+from figcli.test.cli.test_utils import TestUtils
 from figcli.utils.utils import *
 import uuid
 import time
@@ -30,7 +31,7 @@ class DevSync(FiggyTest):
         self.sync_with_orphans()
 
     def prep_sync(self):
-        put = DevPut(extra_args=self.extra_args)
+        put = PutAction(extra_args=self.extra_args)
         put.add('/app/ci-test/v1/config9', DELETE_ME_VALUE, desc='desc', add_more=True)
         put.add('/app/ci-test/v1/config11', DELETE_ME_VALUE, desc='desc', add_more=True)
         put.add('/shared/jordan/testrepl', DELETE_ME_VALUE, desc='desc', add_more=True)
@@ -38,16 +39,14 @@ class DevSync(FiggyTest):
         put.add('/shared/jordan/testrepl3', DELETE_ME_VALUE, desc='desc', add_more=True)
         put.add('/shared/jordan/testrepl4', DELETE_ME_VALUE, desc='desc', add_more=False)
         print("EXECUTING DELETE!!!!")
-        delete = DevDelete(extra_args=self.extra_args)
+        delete = DeleteAction(extra_args=self.extra_args)
         delete.delete(self.missing_key)
 
     def sync_success(self):
         print(f"Testing: {CLI_NAME} config {Utils.get_first(sync)} --env {DEFAULT_ENV} "
               f"--config figcli/test/assets/success/figgy.json")
-        child = pexpect.spawn(f'{CLI_NAME} config {Utils.get_first(sync)} --env {DEFAULT_ENV} '
-                              f'--config figcli/test/assets/success/figgy.json --skip-upgrade {self.extra_args}',
-                              encoding='utf-8', timeout=20)
-        child.logfile = sys.stdout
+        child = TestUtils.spawn(f'{CLI_NAME} config {Utils.get_first(sync)} --env {DEFAULT_ENV} '
+                              f'--config figcli/test/assets/success/figgy.json --skip-upgrade {self.extra_args}')
         missing_key = '/app/ci-test/v1/config12'
         child.expect(f'.*Please input a value for.*{missing_key}.*')
         child.sendline(DELETE_ME_VALUE)
@@ -59,10 +58,10 @@ class DevSync(FiggyTest):
 
     def sync_multi_level_success(self):
         missing_key = '/app/dev/thing/ci-test2/app/ci-test/v1/config12'
-        delete = DevDelete(extra_args=self.extra_args)
+        delete = DeleteAction(extra_args=self.extra_args)
         delete.delete(missing_key)
 
-        put = DevPut(extra_args=self.extra_args)
+        put = PutAction(extra_args=self.extra_args)
         put.add('/app/dev/thing/ci-test2/config9', DELETE_ME_VALUE, desc='desc', add_more=True)
         put.add('/app/dev/thing/ci-test2/config11', DELETE_ME_VALUE, desc='desc', add_more=True)
         put.add('/shared/jordan/testrepl', DELETE_ME_VALUE, desc='desc', add_more=True)
@@ -72,9 +71,9 @@ class DevSync(FiggyTest):
 
         print(f"Testing: {CLI_NAME} config {Utils.get_first(sync)} --env {DEFAULT_ENV} "
               f"--config figcli/test/assets/success/multi-level-ns.json")
-        child = pexpect.spawn(f'{CLI_NAME} config {Utils.get_first(sync)} --env {DEFAULT_ENV} '
-                              f'--config figcli/test/assets/success/multi-level-ns.json --skip-upgrade {self.extra_args}',
-                              encoding='utf-8', timeout=20)
+        child = TestUtils.spawn(f'{CLI_NAME} config {Utils.get_first(sync)} --env {DEFAULT_ENV} '
+                                f'--config figcli/test/assets/success/multi-level-ns.json --skip-upgrade'
+                                f' {self.extra_args}')
 
         child.expect(f'.*Please input a value for.*{missing_key}.*')
         child.sendline(DELETE_ME_VALUE)
@@ -85,13 +84,13 @@ class DevSync(FiggyTest):
         child.expect('.*Sync completed with no errors.*')
 
     def sync_with_orphans(self):
-        delete = DevDelete(extra_args=self.extra_args)
+        delete = DeleteAction(extra_args=self.extra_args)
         delete.delete(self.missing_key)
         print("Successful sync + prune passed!")
 
         print(f"Testing: {CLI_NAME} config {Utils.get_first(sync)} --env {DEFAULT_ENV} "
               f"--config figcli/test/assets/error/figgy.json")
-        child = pexpect.spawn(f'{CLI_NAME} config {Utils.get_first(sync)} --env {DEFAULT_ENV} '
-                              f'--config figcli/test/assets/error/figgy.json --skip-upgrade {self.extra_args}', timeout=20)
+        child = TestUtils.spawn(f'{CLI_NAME} config {Utils.get_first(sync)} --env {DEFAULT_ENV} '
+                                f'--config figcli/test/assets/error/figgy.json --skip-upgrade {self.extra_args}')
         child.expect('.*Unused Parameter:.*/app/ci-test/v1/config11.*')
         print("Sync with stray configs passed!")
