@@ -17,6 +17,8 @@ class FiggyTest(ABC):
             print(f"{c.fg_yl}Testing command: {child.args}{c.rs}")
             self._child = child
             self._child.logfile = sys.stdout
+            self._child.delayafterread = .1
+            self._child.delaybeforesend = .25
 
     @abstractmethod
     def run(self):
@@ -37,4 +39,8 @@ class FiggyTest(ABC):
     def step(self, step_msg: str):
         print(f"{self.c.fg_bl}-----------------------------------------{self.c.rs}")
         print(f"{self.c.fg_yl} STEP: {step_msg}{self.c.rs}")
-        print(f"{self.c.fg_bl}-----------------------------------------{self.c.rs}")
\ No newline at end of file
+        print(f"{self.c.fg_bl}-----------------------------------------{self.c.rs}")
+
+    def wait(self):
+        print("Waiting for child process to exit...")
+        self._child.wait()
\ No newline at end of file
